@@ -1,6 +1,7 @@
-// $Id: checkbutton.cc,v 1.6 1998/09/24 13:19:44 cvs_christof Exp $
+// $Id: checkbutton.cc,v 1.13 2001/10/11 14:07:24 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
  *  Copyright (C) 1998  Christof Petig
+ *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,27 +18,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "writers.hh"
+#include "checkbutton.hh"
 
-void Gtk_CheckButton::Include(File &f,const Widget &w)
-{  f.include("gtk--/checkbutton.h");
-}
+static Gtk_CheckButton Gtk_CheckButton(false);
 
-void Gtk_CheckButton::Declare(File &f,const Widget &w)
-{  StandardWriter::Declare(f,w,"Gtk_CheckButton");
+const std::string Gtk_CheckButton::TypeName(const Widget &w) const
+{  return GtkPrefix()+"CheckButton";
 }
-
-void Gtk_CheckButton::Construct(File &f,const Widget &w,bool is_member)
-{  // 2do if !found("label")
-   f << StandardWriter::ConstructName(f,w,is_member,"Gtk_CheckButton");
-   f << "(\"" << f.CString(w.getString("label"))
-	<< "\")";
+const std::string Gtk_CheckButton::IncludeName(const Widget &w) const
+{  return "gtk--/checkbutton.h";
 }
-
-bool Gtk_CheckButton::NeedConstruct(const Widget &w,bool is_member)
-{  return w.hasTag("label");
-}
-
-void Gtk_CheckButton::Customize(File &f,const Widget &w,const string instance)
-{  Gtk_ToggleButton::Customize(f,w,instance);
+Gtk_CheckButton::Gtk_CheckButton(bool base_class_init)
+{  if (!base_class_init) Writer["GtkCheckButton"]=this;
 }
