@@ -1,6 +1,6 @@
-// $Id: placeholder.cc,v 1.2 1998/09/24 13:19:47 cvs_christof Exp $
+// $Id: placeholder.cc,v 1.12 2001/10/11 14:07:24 christof Exp $
 /*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
- *  Copyright (C) 1998  Christof Petig
+ *  Copyright (C) 1999  Adolf Petig GmbH & Co. KG, written by Christof Petig
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,24 +17,28 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "writers.hh"
+#include "WriterBase.hh"
 
-void Placeholder::Include(File &f,const Widget &w)
-{  
-}
+class Placeholder : public WriterBase
+{public:
+	typedef WriterBase Parent;
+	virtual const std::string TypeName(const Widget &w) const
+	{  return ""; }
+	virtual const std::string IncludeName(const Widget &w) const
+	{  return ""; }
+	Placeholder();
+	virtual void GHDeclaration(const Widget &w, CxxFile &f) const
+	{}
+#if 0 // not needed
+	virtual bool NeedExplicitCtor(const Widget &w) const
+	{  return false; }
+	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
+	{  f.FunctionArg(); }
+#endif	
+};
 
-void Placeholder::Declare(File &f,const Widget &w)
-{  f << "// here's a placeholder";
-}
+static Placeholder Placeholder;
 
-void Placeholder::Construct(File &f,const Widget &w,bool is_member)
-{  
-}
-
-bool Placeholder::NeedConstruct(const Widget &w,bool is_member)
-{  return false;
-}
-
-void Placeholder::Customize(File &f,const Widget &w,const string instance)
-{  f << "// here's a placeholder\n\t";
+Placeholder::Placeholder()
+{  Writer["Placeholder"]=this;
 }
